@@ -9,7 +9,7 @@ use Data::Printer;
 
 with 'WebService::Client';
 # ABSTRACT: Perl 5 interface to Pixabay API.
-our $VERSION = '0.0.1'; # VERSION
+our $VERSION = '0.0.2'; # VERSION
 
 has api_key =>
 (
@@ -57,7 +57,6 @@ method video_search
 	);
 }
 
-
 method show_data_structure($method_name)
 {
 	return p $method_name;
@@ -65,6 +64,8 @@ method show_data_structure($method_name)
 
 1;
 
+__END__
+
 =pod
 
 =encoding UTF-8
@@ -75,24 +76,7 @@ WebService::Pixabay - Perl 5 interface to Pixabay API.
 
 =head1 VERSION
 
-version 0.0.1
-
-=head1 AUTHOR
-
-faraco <skelic3@gmail.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2017 by faraco.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
-__DATA__
-
-=pod
+version 0.0.2
 
 =head1 SYNOPSIS
 
@@ -107,9 +91,14 @@ __DATA__
 	$pix->show_data_structure($img_search);
 	$pix->show_data_structure($vid_search);
 	
-	# example custom searches
+	###################################################
+	# The parameters of the method have the same name #
+	# and default values as in Pixabay API docs       #
+	###################################################
+
+	# example custom image search
 	my $nis = $pix->image_search(
-		q => 'cats dog'.
+		q => 'cats dog',
 		en => 'es',
 		response_group => 'high_resolution',
 		image_type => 'illustration',
@@ -121,23 +110,38 @@ __DATA__
 		pretty => 'true'
 	);
 
+	# example custom video search
+	my $nvs = $pix->video_search(
+		q => 'tree',
+		en = 'en',
+		pretty => 'false',
+		page => 3,
+		order => 'popular'
+	);
+
+
 	$pix->show_data_structure($nis);
+	$pix->show_data_structure($nvs);
 
 =head1 SEE ALSO
 
 L<Pixabay API documentations|https://pixabay.com/api/docs>
-
 L<Moo>
-
 L<Function::Parameters>
-
 L<Test::More>
-
 L<WebService::Client>
-
 L<LWP::Online>
-
 L<Data::Printer>
 
-=cut
+=head1 AUTHOR
 
+faraco <skelic3@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by faraco.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
